@@ -44,6 +44,16 @@ class Hx():
         cang_df = pd.read_csv(StringIO(s),dtype={'证券代码': object,'可用余额':int},usecols=[0,1,2,3,4,5,6,7,8,9,10])
         cang_df.drop(cang_df[cang_df['可用余额'] == 0].index, inplace=True)
         return cang_df
+    #用最新价格更新持仓
+    def updata_cang(self,cang_df):
+        temp_list = []
+        for code in cang_df['证券代码'].values:
+            if code[:2]=='11':code='sh'+code
+            else:code='sz'+code
+            temp_list.append(self.get_real_data(code)['price'])
+        cang_df['市价']=temp_list
+        cang_df['市值']=cang_df['市价']*cang_df['股票余额']
+        return cang_df
     #获取资金
     def get_money(self):
         global hwnd,left_window,main_window
@@ -121,10 +131,10 @@ class Hx():
                 self.sell(code,price,num)
                 time.sleep(0.3)
     #梭哈
-    def soha(self):
-        money = float(self.get_money()['可用余额'])/20
+    def soha(self,n=20):
+        money = float(self.get_money()['可用余额'])/n
         data = self.get_kzz_list()
-        zz_list = list(data['转债代码'].values[3:23])
+        zz_list = list(data['转债代码'].values[:n])
         print(zz_list)
         for code in zz_list:
             self.close_pop()
@@ -133,7 +143,7 @@ class Hx():
             price = round(price*1.01,2)
             num=int(money//price)//10*10
             print(code,price,num)
-            if num>-10:
+            if num > 0:
                 self.buy(code,price,num)
         time.sleep(0.3)
         self.close_pop()
@@ -183,6 +193,8 @@ class Hx():
         data=data[~data['强赎'].str.contains('最后交易日',na=False)]#.contains('最后交易日')]
         data.drop('强赎',axis=1,inplace=True)
         data = data.sort_values(by="涨跌幅",ascending=False)
+        data = data[(data['现价']>100) & (data['现价']<400)]
+        data = data[data['涨跌幅']<8]
         data = data.reset_index(drop=True)
         return data
 
